@@ -9,7 +9,7 @@ try:
                                        V1alpha1ResourceTemplate,
                                        V1alpha1ScriptTemplate,
                                        V1alpha1Template,
-                                       V1ConfigMapKeySelector,
+                                       V1ConfigMapKeySelector, V1EnvVar,
                                        V1ResourceRequirements, V1Volume,
                                        V1VolumeMount)
     from argo.workflows.client.configuration import Configuration
@@ -63,8 +63,7 @@ class OPTemplate:
             assert isinstance(value, Outputs)
             value.set_template(self)
 
-    def handle_key(self, memoize_prefix=None,
-                   memoize_configmap="dflow-config"):
+    def handle_key(self, memoize_prefix=None, memoize_configmap="dflow"):
         if "dflow_key" in self.inputs.parameters:
             if memoize_prefix is not None:
                 self.memoize_key = "%s-{{inputs.parameters.dflow_key}}" \
@@ -83,7 +82,7 @@ class OPTemplate:
                 key=self.memoize_key,
                 local_vars_configuration=config, cache=V1alpha1Cache(
                     config_map=V1ConfigMapKeySelector(
-                        name=memoize_configmap,
+                        name="%s-%s" % (memoize_configmap, self.memoize_key),
                         local_vars_configuration=config)))
 
 
@@ -109,6 +108,7 @@ class ScriptOPTemplate(OPTemplate):
         annotations: annotations for the OP template
         requests: a dict of resource requests
         limits: a dict of resource limits
+        envs: environment variables
     """
 
     def __init__(
@@ -131,6 +131,7 @@ class ScriptOPTemplate(OPTemplate):
             image_pull_policy: str = None,
             requests: Dict[str, str] = None,
             limits: Dict[str, str] = None,
+            envs: Dict[str, str] = None,
             **kwargs,
     ) -> None:
         super().__init__(name=name, inputs=inputs, outputs=outputs,
@@ -154,9 +155,10 @@ class ScriptOPTemplate(OPTemplate):
         self.image_pull_policy = image_pull_policy
         self.requests = requests
         self.limits = limits
+        self.envs = envs
 
     def convert_to_argo(self, memoize_prefix=None,
-                        memoize_configmap="dflow-config"):
+                        memoize_configmap="dflow"):
         self.handle_key(memoize_prefix, memoize_configmap)
         self.annotations["workflows.argoproj.io/progress"] = self.init_progress
         if self.resource is not None:
@@ -171,6 +173,10 @@ class ScriptOPTemplate(OPTemplate):
                                     volumes=self.volumes,
                                     resource=self.resource)
         else:
+            if self.envs is not None:
+                env = [V1EnvVar(name=k, value=v) for k, v in self.envs.items()]
+            else:
+                env = None
             return \
                 V1alpha1Template(name=self.name,
                                  metadata=V1alpha1Metadata(
@@ -188,7 +194,8 @@ class ScriptOPTemplate(OPTemplate):
                                      volume_mounts=self.mounts,
                                      resources=V1ResourceRequirements(
                                          limits=self.limits,
-                                         requests=self.requests)))
+                                         requests=self.requests),
+                                     env=env))
 
 
 class ShellOPTemplate(ScriptOPTemplate):
@@ -213,6 +220,7 @@ class ShellOPTemplate(ScriptOPTemplate):
         annotations: annotations for the OP template
         requests: a dict of resource requests
         limits: a dict of resource limits
+        envs: environment variables
     """
 
     def __init__(
@@ -234,6 +242,7 @@ class ShellOPTemplate(ScriptOPTemplate):
         image_pull_policy: str = None,
         requests: Dict[str, str] = None,
         limits: Dict[str, str] = None,
+        envs: Dict[str, str] = None,
         **kwargs,
     ) -> None:
         if command is None:
@@ -244,7 +253,7 @@ class ShellOPTemplate(ScriptOPTemplate):
             init_progress=init_progress, timeout=timeout,
             retry_strategy=retry_strategy, memoize_key=memoize_key, pvcs=pvcs,
             image_pull_policy=image_pull_policy, annotations=annotations,
-            requests=requests, limits=limits)
+            requests=requests, limits=limits, envs=envs)
 
 
 class PythonScriptOPTemplate(ScriptOPTemplate):
@@ -269,6 +278,7 @@ class PythonScriptOPTemplate(ScriptOPTemplate):
         annotations: annotations for the OP template
         requests: a dict of resource requests
         limits: a dict of resource limits
+        envs: environment variables
     """
 
     def __init__(
@@ -290,6 +300,7 @@ class PythonScriptOPTemplate(ScriptOPTemplate):
         image_pull_policy: str = None,
         requests: Dict[str, str] = None,
         limits: Dict[str, str] = None,
+        envs: Dict[str, str] = None,
         **kwargs,
     ) -> None:
         if command is None:
@@ -300,4 +311,4 @@ class PythonScriptOPTemplate(ScriptOPTemplate):
             init_progress=init_progress, timeout=timeout,
             retry_strategy=retry_strategy, memoize_key=memoize_key, pvcs=pvcs,
             image_pull_policy=image_pull_policy, annotations=annotations,
-            requests=requests, limits=limits)
+            requests=requests, limits=limits, envs=envs)
