@@ -16,6 +16,14 @@ except Exception:
     pass
 
 
+def update_dict(d1: dict, d2: dict) -> None:
+    for k, v in d2.items():
+        if isinstance(v, dict) and k in d1 and isinstance(d1[k], dict):
+            update_dict(d1[k], v)
+        else:
+            d1[k] = v
+
+
 class DispatcherExecutor(Executor):
     """
     Dispatcher executor
@@ -27,6 +35,7 @@ class DispatcherExecutor(Executor):
         username: username
         private_key_file: private key file for SSH
         image: image for dispatcher
+        image: image pull policy for dispatcher
         command: command for dispatcher
         remote_command: command for running the script remotely
         map_tmp_dir: map /tmp to ./tmp
@@ -46,6 +55,7 @@ class DispatcherExecutor(Executor):
                  username: str = "root",
                  private_key_file: os.PathLike = None,
                  image: str = None,
+                 image_pull_policy: str = None,
                  command: Union[str, List[str]] = "python",
                  remote_command: Union[str, List[str]] = None,
                  map_tmp_dir: bool = True,
@@ -65,6 +75,9 @@ class DispatcherExecutor(Executor):
         if image is None:
             image = config["dispatcher_image"]
         self.image = image
+        if image_pull_policy is None:
+            image_pull_policy = config["dispatcher_image_pull_policy"]
+        self.image_pull_policy = image_pull_policy
         if isinstance(command, str):
             command = [command]
         self.command = command
@@ -98,9 +111,9 @@ class DispatcherExecutor(Executor):
             }
         }
         if "machine" in conf:
-            self.machine_dict.update(conf["machine"])
+            update_dict(self.machine_dict, conf["machine"])
         if machine_dict is not None:
-            self.machine_dict.update(machine_dict)
+            update_dict(self.machine_dict, machine_dict)
 
         # set env to prevent dispatcher from considering different tasks as one
         self.resources_dict = {
@@ -115,9 +128,9 @@ class DispatcherExecutor(Executor):
             }
         }
         if "resources" in conf:
-            self.resources_dict.update(conf["resources"])
+            update_dict(self.resources_dict, conf["resources"])
         if resources_dict is not None:
-            self.resources_dict.update(resources_dict)
+            update_dict(self.resources_dict, resources_dict)
 
         self.task_dict = {
             "task_work_path": "./",
@@ -125,12 +138,13 @@ class DispatcherExecutor(Executor):
             "errlog": "err"
         }
         if task_dict is not None:
-            self.task_dict.update(task_dict)
+            update_dict(self.task_dict, task_dict)
 
     def render(self, template):
         new_template = deepcopy(template)
         new_template.name += "-" + randstr()
         new_template.image = self.image
+        new_template.image_pull_policy = self.image_pull_policy
         new_template.command = self.command
 
         remote_command = template.command if self.remote_command is None \
