@@ -101,6 +101,7 @@ class PythonOPTemplate(PythonScriptOPTemplate):
         image_pull_policy: Always, IfNotPresent, Never
         requests: a dict of resource requests
         limits: a dict of resource limits
+        envs: environment variables
     """
 
     def __init__(self,
@@ -130,6 +131,7 @@ class PythonOPTemplate(PythonScriptOPTemplate):
                  requests: Dict[str, str] = None,
                  limits: Dict[str, str] = None,
                  upload_dflow: bool = True,
+                 envs: Dict[str, str] = None,
                  **kwargs,
                  ) -> None:
         op = None
@@ -167,7 +169,7 @@ class PythonOPTemplate(PythonScriptOPTemplate):
         super().__init__(name="%s-%s" % (class_name, "".join(random.sample(
             string.digits + string.ascii_lowercase, 5))), inputs=Inputs(),
             outputs=Outputs(), volumes=volumes, mounts=mounts,
-            requests=requests, limits=limits)
+            requests=requests, limits=limits, envs=envs)
         self.slices = slices
         if timeout is not None:
             self.timeout = "%ss" % timeout
@@ -282,7 +284,8 @@ class PythonOPTemplate(PythonScriptOPTemplate):
         if op_class.__module__ == "__main__":
             try:
                 source_lines, start_line = inspect.getsourcelines(op_class)
-                with open(inspect.getsourcefile(op_class), "r") as fd:
+                with open(inspect.getsourcefile(op_class), "r",
+                          encoding="utf-8") as fd:
                     pre_lines = fd.readlines()[:start_line-1]
                 script += "".join(pre_lines + source_lines) + "\n"
             except Exception:
