@@ -13,7 +13,7 @@ from .io import (PVC, ArgoVar, InputArtifact, InputParameter, OutputArtifact,
 from .op_template import OPTemplate, PythonScriptOPTemplate, ShellOPTemplate
 from .resource import Resource
 from .util_ops import CheckNumSuccess, CheckSuccessRatio
-from .utils import catalog_of_artifact, upload_artifact
+from .utils import catalog_of_artifact, randstr, upload_artifact
 
 try:
     from argo.workflows.client import (V1alpha1Arguments, V1alpha1ContinueOn,
@@ -137,6 +137,7 @@ class Step:
         executor: define the executor to execute the script
         use_resource: use k8s resource
         util_image: image for utility step
+        util_image_pull_policy: image pull policy for utility step
         util_command: command for utility step
     """
 
@@ -158,6 +159,7 @@ class Step:
             executor: Executor = None,
             use_resource: Resource = None,
             util_image: str = None,
+            util_image_pull_policy: str = None,
             util_command: Union[str, List[str]] = None,
             **kwargs,
     ) -> None:
@@ -189,6 +191,9 @@ class Step:
         if util_image is None:
             util_image = config["util_image"]
         self.util_image = util_image
+        if util_image_pull_policy is None:
+            util_image_pull_policy = config["util_image_pull_policy"]
+        self.util_image_pull_policy = util_image_pull_policy
         if isinstance(util_command, str):
             util_command = [util_command]
         self.util_command = util_command
@@ -215,7 +220,7 @@ class Step:
                     self.template.slices.sub_path and
                     self.template.slices.input_artifact)):
             new_template = deepcopy(self.template)
-            new_template.name = self.template.name + "-" + self.name
+            new_template.name = self.template.name + "-" + randstr()
             script = "import os, json\n"
             for name in new_template.slices.output_artifact:
                 script += "os.makedirs('/tmp/outputs/artifacts/%s/%s', "\
@@ -226,7 +231,7 @@ class Step:
             init_template = PythonScriptOPTemplate(
                 name="%s-init-artifact" % new_template.name,
                 image=self.util_image, command=self.util_command,
-                image_pull_policy=new_template.image_pull_policy,
+                image_pull_policy=self.util_image_pull_policy,
                 script=script)
             if self.key is not None:
                 new_template.inputs.parameters["dflow_group_key"] = \
@@ -432,7 +437,7 @@ class Step:
         if len(pvc_arts) > 0:
             if new_template is None:
                 new_template = deepcopy(self.template)
-                new_template.name = self.template.name + "-" + self.name
+                new_template.name = self.template.name + "-" + randstr()
             if (isinstance(new_template, ShellOPTemplate)):
                 for pvc, art in pvc_arts:
                     del new_template.inputs.artifacts[art.name]
@@ -464,7 +469,7 @@ class Step:
         if len(pvc_arts) > 0:
             if new_template is None:
                 new_template = deepcopy(self.template)
-                new_template.name = self.template.name + "-" + self.name
+                new_template.name = self.template.name + "-" + randstr()
             if (isinstance(new_template, ShellOPTemplate)):
                 new_template.script += "\n"
                 for pvc, art in pvc_arts:
@@ -491,7 +496,7 @@ class Step:
             self.continue_on_failed = True
             if new_template is None:
                 new_template = deepcopy(self.template)
-                new_template.name = self.template.name + "-" + self.name
+                new_template.name = self.template.name + "-" + randstr()
             if (isinstance(new_template, ShellOPTemplate)):
                 new_template.outputs.parameters["dflow_success_tag"] = \
                     OutputParameter(value_from_path="/tmp/success_tag",
@@ -518,7 +523,9 @@ class Step:
         if self.continue_on_num_success is not None:
             self.check_step = self.__class__(
                 name="%s-check-num-success" % self.name,
-                template=CheckNumSuccess(image=self.util_image),
+                template=CheckNumSuccess(
+                    image=self.util_image,
+                    image_pull_policy=self.util_image_pull_policy),
                 parameters={
                     "success": self.outputs.parameters["dflow_success_tag"],
                     "threshold": self.continue_on_num_success
@@ -527,7 +534,9 @@ class Step:
         elif self.continue_on_success_ratio is not None:
             self.check_step = self.__class__(
                 name="%s-check-success-ratio" % self.name,
-                template=CheckSuccessRatio(image=self.util_image),
+                template=CheckSuccessRatio(
+                    image=self.util_image,
+                    image_pull_policy=self.util_image_pull_policy),
                 parameters={
                     "success": self.outputs.parameters["dflow_success_tag"],
                     "threshold": self.continue_on_success_ratio
