@@ -157,9 +157,9 @@ class Workflow:
         status = None
         if reuse_step is not None:
             self.id = self.name + "-" + randstr()
-            data = {}
             copied_keys = []
             for step in reuse_step:
+                data = {}
                 if step.key is None:
                     continue
                 outputs = {}
@@ -205,30 +205,30 @@ class Workflow:
                     "creationTimestamp": step.finishedAt,
                     "lastHitTimestamp": step.finishedAt
                 })
-            cm_name = "dflow-" + randstr()
-            config_map = kubernetes.client.V1ConfigMap(
-                data=data, metadata=kubernetes.client.V1ObjectMeta(
-                    name=cm_name))
-            if self.k8s_api_server is not None:
-                k8s_configuration = kubernetes.client.Configuration(
-                    host=self.k8s_api_server)
-                k8s_configuration.verify_ssl = False
-                if self.token is None:
-                    k8s_client = kubernetes.client.ApiClient(k8s_configuration)
+                config_map = kubernetes.client.V1ConfigMap(
+                    data=data, metadata=kubernetes.client.V1ObjectMeta(
+                        name="dflow-%s-%s" % (self.id, step.key)))
+                if self.k8s_api_server is not None:
+                    k8s_configuration = kubernetes.client.Configuration(
+                        host=self.k8s_api_server)
+                    k8s_configuration.verify_ssl = False
+                    if self.token is None:
+                        k8s_client = kubernetes.client.ApiClient(
+                            k8s_configuration)
+                    else:
+                        k8s_client = kubernetes.client.ApiClient(
+                            k8s_configuration, header_name='Authorization',
+                            header_value='Bearer %s' % self.token)
+                    v1 = kubernetes.client.CoreV1Api(k8s_client)
                 else:
-                    k8s_client = kubernetes.client.ApiClient(
-                        k8s_configuration, header_name='Authorization',
-                        header_value='Bearer %s' % self.token)
-                v1 = kubernetes.client.CoreV1Api(k8s_client)
-            else:
-                kubernetes.config.load_kube_config(
-                    config_file=self.k8s_config_file)
-                v1 = kubernetes.client.CoreV1Api()
-            v1.create_namespaced_config_map(namespace=self.namespace,
-                                            body=config_map)
+                    kubernetes.config.load_kube_config(
+                        config_file=self.k8s_config_file)
+                    v1 = kubernetes.client.CoreV1Api()
+                v1.create_namespaced_config_map(namespace=self.namespace,
+                                                body=config_map)
             self.handle_template(
                 self.entrypoint, memoize_prefix=self.id,
-                memoize_configmap=cm_name)
+                memoize_configmap="dflow")
         else:
             self.handle_template(self.entrypoint)
 
@@ -262,7 +262,7 @@ class Workflow:
             status=status)
 
     def handle_template(self, template, memoize_prefix=None,
-                        memoize_configmap="dflow-config"):
+                        memoize_configmap="dflow"):
         if template.name in self.templates:
             assert template == self.templates[template.name], \
                 "Duplication of template name: %s" % template.name
@@ -324,10 +324,11 @@ class Workflow:
 
     def query_step(
             self,
-            name: str = None,
-            key: str = None,
-            phase: str = None,
-            id: str = None,
+            name: Union[str, List[str]] = None,
+            key: Union[str, List[str]] = None,
+            phase: Union[str, List[str]] = None,
+            id: Union[str, List[str]] = None,
+            type: Union[str, List[str]] = None,
     ) -> List[ArgoStep]:
         """
         Query the existing steps of the workflow from Argo
@@ -337,10 +338,12 @@ class Workflow:
             key: filter by key of step
             phase: filter by phase of step
             id: filter by id of step
+            type: filter by type of step
         Returns:
             a list of steps
         """
-        return self.query().get_step(name=name, key=key, phase=phase, id=id)
+        return self.query().get_step(name=name, key=key, phase=phase, id=id,
+                                     type=type)
 
     def query_keys_of_steps(
             self,
@@ -352,3 +355,72 @@ class Workflow:
             a list of keys
         """
         return [step.key for step in self.query_step() if step.key is not None]
+
+    def terminate(self) -> None:
+        """
+        Terminate the workflow
+        """
+        if self.id is None:
+            raise RuntimeError("Workflow ID is None")
+        self.api_instance.api_client.call_api(
+            '/api/v1/workflows/%s/%s/terminate' % (self.namespace, self.id),
+            'PUT')
+
+    def delete(self) -> None:
+        """
+        Delete the workflow
+        """
+        if self.id is None:
+            raise RuntimeError("Workflow ID is None")
+        self.api_instance.api_client.call_api(
+            '/api/v1/workflows/%s/%s' % (self.namespace, self.id), 'DELETE')
+
+    def resubmit(self) -> None:
+        """
+        Resubmit the workflow
+        """
+        if self.id is None:
+            raise RuntimeError("Workflow ID is None")
+        self.api_instance.api_client.call_api(
+            '/api/v1/workflows/%s/%s/resubmit' % (self.namespace, self.id),
+            'PUT')
+
+    def resume(self) -> None:
+        """
+        Resume the workflow
+        """
+        if self.id is None:
+            raise RuntimeError("Workflow ID is None")
+        self.api_instance.api_client.call_api(
+            '/api/v1/workflows/%s/%s/resume' % (self.namespace, self.id),
+            'PUT')
+
+    def retry(self) -> None:
+        """
+        Retry the workflow
+        """
+        if self.id is None:
+            raise RuntimeError("Workflow ID is None")
+        self.api_instance.api_client.call_api(
+            '/api/v1/workflows/%s/%s/retry' % (self.namespace, self.id),
+            'PUT')
+
+    def stop(self) -> None:
+        """
+        Stop the workflow
+        """
+        if self.id is None:
+            raise RuntimeError("Workflow ID is None")
+        self.api_instance.api_client.call_api(
+            '/api/v1/workflows/%s/%s/stop' % (self.namespace, self.id),
+            'PUT')
+
+    def suspend(self) -> None:
+        """
+        Suspend the workflow
+        """
+        if self.id is None:
+            raise RuntimeError("Workflow ID is None")
+        self.api_instance.api_client.call_api(
+            '/api/v1/workflows/%s/%s/suspend' % (self.namespace, self.id),
+            'PUT')
